==> affixapi-1.1.62.tar.gz: affixapi-1.1.62/openapi_client/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_client.model.address_no_non_null_request import AddressNoNonNullRequest
from openapi_client.model.address_response import AddressResponse
from openapi_client.model.client_request import ClientRequest
from openapi_client.model.client_response import ClientResponse
from openapi_client.model.companies20230301_response import Companies20230301Response
from openapi_client.model.company_response import CompanyResponse
from openapi_client.model.create_employee_request import CreateEmployeeRequest
from openapi_client.model.create_employee_request_bank_account import CreateEmployeeRequestBankAccount
from openapi_client.model.create_employee_request_dependents import CreateEmployeeRequestDependents
from openapi_client.model.create_employee_request_emergency_contacts import CreateEmployeeRequestEmergencyContacts
from openapi_client.model.create_employee_request_manager import CreateEmployeeRequestManager
from openapi_client.model.currency_not_null_request import CurrencyNotNullRequest
from openapi_client.model.currency_response import CurrencyResponse
from openapi_client.model.disconnect_response import DisconnectResponse
from openapi_client.model.employee_response import EmployeeResponse
from openapi_client.model.employee_response_manager import EmployeeResponseManager
from openapi_client.model.employees20230301_response import Employees20230301Response
from openapi_client.model.employment_no_null_enum_request import EmploymentNoNullEnumRequest
from openapi_client.model.employment_response import EmploymentResponse
from openapi_client.model.employment_status import EmploymentStatus
from openapi_client.model.employment_status_not_null import EmploymentStatusNotNull
from openapi_client.model.employment_status_not_null_request import EmploymentStatusNotNullRequest
from openapi_client.model.employment_status_response import EmploymentStatusResponse
from openapi_client.model.group_no_null_enum_request import GroupNoNullEnumRequest
from openapi_client.model.group_response import GroupResponse
from openapi_client.model.groups20230301_response import Groups20230301Response
from openapi_client.model.groups_no_null_enum_request import GroupsNoNullEnumRequest
from openapi_client.model.id_and_message_response import IdAndMessageResponse
from openapi_client.model.identity_response import IdentityResponse
from openapi_client.model.inline_response400 import InlineResponse400
from openapi_client.model.inline_response401 import InlineResponse401
from openapi_client.model.inline_response409 import InlineResponse409
from openapi_client.model.introspect_response import IntrospectResponse
from openapi_client.model.location_no_non_null_request import LocationNoNonNullRequest
from openapi_client.model.location_response import LocationResponse
from openapi_client.model.message_response import MessageResponse
from openapi_client.model.mode_request import ModeRequest
from openapi_client.model.mode_response import ModeResponse
from openapi_client.model.payrun_response import PayrunResponse
from openapi_client.model.payruns20230301_response import Payruns20230301Response
from openapi_client.model.payslip_response import PayslipResponse
from openapi_client.model.payslip_response_contributions import PayslipResponseContributions
from openapi_client.model.payslip_response_deductions import PayslipResponseDeductions
from openapi_client.model.payslip_response_earnings import PayslipResponseEarnings
from openapi_client.model.payslip_response_taxes import PayslipResponseTaxes
from openapi_client.model.payslips20230301_response import Payslips20230301Response
from openapi_client.model.provider_request import ProviderRequest
from openapi_client.model.provider_response import ProviderResponse
from openapi_client.model.providers_response import ProvidersResponse
from openapi_client.model.scopes_request import ScopesRequest
from openapi_client.model.scopes_response import ScopesResponse
from openapi_client.model.time_off_balance_response import TimeOffBalanceResponse
from openapi_client.model.time_off_balances20230301_response import TimeOffBalances20230301Response
from openapi_client.model.time_off_entries20230301_response import TimeOffEntries20230301Response
from openapi_client.model.time_off_entry_response import TimeOffEntryResponse
from openapi_client.model.timesheet_response import TimesheetResponse
from openapi_client.model.timesheets20230301_response import Timesheets20230301Response
from openapi_client.model.token_request import TokenRequest
from openapi_client.model.token_response import TokenResponse
from openapi_client.model.tokens_response import TokensResponse
from openapi_client.model.work_locations20230301_response import WorkLocations20230301Response

==> affixapi-1.1.70.tar.gz: affixapi-1.1.70/openapi_client/models/__init__.py <==
# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from openapi_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_client.model.address_no_non_null_request import AddressNoNonNullRequest
from openapi_client.model.address_response import AddressResponse
from openapi_client.model.client_request import ClientRequest
from openapi_client.model.client_response import ClientResponse
from openapi_client.model.companies20230301_response import Companies20230301Response
from openapi_client.model.company_response import CompanyResponse
from openapi_client.model.create_employee_request import CreateEmployeeRequest
from openapi_client.model.create_employee_request_bank_account import CreateEmployeeRequestBankAccount
from openapi_client.model.create_employee_request_dependents import CreateEmployeeRequestDependents
from openapi_client.model.create_employee_request_emergency_contacts import CreateEmployeeRequestEmergencyContacts
from openapi_client.model.create_employee_request_manager import CreateEmployeeRequestManager
from openapi_client.model.currency_not_null_request import CurrencyNotNullRequest
from openapi_client.model.currency_response import CurrencyResponse
from openapi_client.model.disconnect_response import DisconnectResponse
from openapi_client.model.employee_response import EmployeeResponse
from openapi_client.model.employee_response_manager import EmployeeResponseManager
from openapi_client.model.employees20230301_response import Employees20230301Response
from openapi_client.model.employment_no_null_enum_request import EmploymentNoNullEnumRequest
from openapi_client.model.employment_response import EmploymentResponse
from openapi_client.model.employment_status_not_null_not_nullable import EmploymentStatusNotNullNotNullable
from openapi_client.model.employment_status_not_null_request import EmploymentStatusNotNullRequest
from openapi_client.model.employment_status_response import EmploymentStatusResponse
from openapi_client.model.group_no_null_enum_request import GroupNoNullEnumRequest
from openapi_client.model.group_response import GroupResponse
from openapi_client.model.groups20230301_response import Groups20230301Response
from openapi_client.model.groups_no_null_enum_request import GroupsNoNullEnumRequest
from openapi_client.model.id_and_message_response import IdAndMessageResponse
from openapi_client.model.identity_response import IdentityResponse
from openapi_client.model.inline_response400 import InlineResponse400
from openapi_client.model.inline_response401 import InlineResponse401
from openapi_client.model.inline_response409 import InlineResponse409
from openapi_client.model.introspect_response import IntrospectResponse
from openapi_client.model.location_no_non_null_request import LocationNoNonNullRequest
from openapi_client.model.location_response import LocationResponse
from openapi_client.model.message_response import MessageResponse
from openapi_client.model.mode_request import ModeRequest
from openapi_client.model.mode_response import ModeResponse
from openapi_client.model.payrun_response import PayrunResponse
from openapi_client.model.payruns20230301_response import Payruns20230301Response
from openapi_client.model.payslip_response import PayslipResponse
from openapi_client.model.payslip_response_contributions import PayslipResponseContributions
from openapi_client.model.payslip_response_deductions import PayslipResponseDeductions
from openapi_client.model.payslip_response_earnings import PayslipResponseEarnings
from openapi_client.model.payslip_response_taxes import PayslipResponseTaxes
from openapi_client.model.payslips20230301_response import Payslips20230301Response
from openapi_client.model.policy_type_response import PolicyTypeResponse
from openapi_client.model.provider_request import ProviderRequest
from openapi_client.model.provider_response import ProviderResponse
from openapi_client.model.providers_response import ProvidersResponse
from openapi_client.model.scopes_request import ScopesRequest
from openapi_client.model.scopes_response import ScopesResponse
from openapi_client.model.time_off_balance_response import TimeOffBalanceResponse
from openapi_client.model.time_off_balances20230301_response import TimeOffBalances20230301Response
from openapi_client.model.time_off_entries20230301_response import TimeOffEntries20230301Response
from openapi_client.model.time_off_entry_response import TimeOffEntryResponse
from openapi_client.model.timesheet_response import TimesheetResponse
from openapi_client.model.timesheets20230301_response import Timesheets20230301Response
from openapi_client.model.token_request import TokenRequest
from openapi_client.model.token_response import TokenResponse
from openapi_client.model.tokens_response import TokensResponse
from openapi_client.model.work_locations20230301_response import WorkLocations20230301Response
